@@ -60,7 +60,7 @@ fload <- function(json,
                   on_query_error = NULL,
                   max_simplify_lvl = c("data_frame", "matrix", "vector", "list"),
                   type_policy = c("anything_goes", "numbers", "strict"),
-                  int64_policy = c("double", "string", "integer64"),
+                  int64_policy = c("double", "string", "integer64", "always"),
                   verbose = FALSE,
                   temp_dir = tempdir(),
                   keep_temp_files = FALSE,
@@ -134,14 +134,15 @@ fload <- function(json,
     # int64_policy -------------------------------------------------------------
     if (is.character(int64_policy)) {
         int64_policy <- switch(
-            match.arg(int64_policy, c("double", "string", "integer64")),
+            match.arg(int64_policy, c("double", "string", "integer64", "always")),
             double = 0L,
             string = 1L,
             integer64 = 2L,
+            always = 3L,
             stop("Unknown `int64_policy=`.")
         )
     } else if (is.numeric(int64_policy)) {
-        stopifnot(int64_policy %in% 0:2)
+        stopifnot(int64_policy %in% 0:3)
     } else {
         stop("`int64_policy` must be of type `character` or `numeric`.")
     }
